	/*
 * Copyright (C) 2014 Mikel Penagarikano
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package edu.gtts.mediaevalquesst2015;

import java.io.File;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.parsers.SAXParser;
import javax.xml.parsers.SAXParserFactory;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.xml.sax.SAXParseException;

/**
 *
 * @author mpenagar
 */
public class ECF {
	
	public static Map<String,Integer> load(final String fileName, boolean quiet) throws ParserConfigurationException, SAXException, IOException {
		final Map<String,Integer> indexMap = new HashMap<String,Integer>();	
		SAXParserFactory fac = SAXParserFactory.newInstance();
		fac.setValidating(false);
		SAXParser parser = fac.newSAXParser();
		
		try {
			if (!quiet) System.out.print("Loading ecf file: " + fileName + " ... ");
			parser.parse(new File(fileName), new LocatedHandler(){
				public void startElement(String uri, String localName, String qName, Attributes attributes) throws SAXException {
					if (qName.compareTo("excerpt") == 0) {
						String name = attributes.getValue("audio_filename");
						checkAttribute("audio_filename", name);
						// id pattern is: "path/to/id.ext"
						String id = name.replaceFirst(".*/","").replaceFirst("[.][^.]+$", "");
						if (id.length() == 0) {
							throwLocatedSAXParseException("Could not parse id (path/to/id.ext) from filename: \"" + name + "\"");
						} else if (indexMap.put(id,indexMap.size()) != null) {
							throwLocatedSAXParseException("Duplicated audio name : \"" + name + "\"");
						}
					}
				}
			});
			if (!quiet) System.out.println(" Done (size: " + indexMap.size() + ")");
		} catch (SAXParseException ex) {
			System.err.println("Parse Exception at line " + ex.getLineNumber() + " while parsing \"" + fileName + "\" :\n\n " + ex.getLocalizedMessage() + "\n");
			System.exit(1);
		}
		return indexMap;
	}
}
