#!/usr/bin/env bash

# $1: list of systems to score (absolute paths of folders containing a .stdlist.xml.gzip file)
systems=$1

# directory containing the scoring script, the .jar file and the ground-truth folders
scoring_dir=.

for system in $(cat $systems); do
	echo $(basename $system)

	gunzip $system/*.gz

	# The strings 'eval' or 'dev' in the system name determine the groundtruth to be used
	dev_eval=$(basename $system | sed -E 's/.*(dev|DEV|eval|EVAL).*/\1/' | sed 's/EVAL/eval/' | sed 's/DEV/dev/')

	echo "Set of queries: $dev_eval"

	# We determine whether a floor score has to be used or not
	floor=$(basename $system | sed -E 's/.*_([^_]*)/\1/')

	echo "Floor score: $floor"

	for t in T1 T2 T3; do

		echo "Matching type: $t"

		# Target directory, where results will be stored
		mkdir $system/$t
		mv $system/*.stdlist.xml $system/$t

		groundtruth=groundtruth_quesst2015_"$dev_eval"_"$t"

		if [[ $floor == "auto" ]]; then
			$scoring_dir/score-TWV-Cnxe.sh $system/$t $scoring_dir/$groundtruth
		else
			$scoring_dir/score-TWV-Cnxe.sh $system/$t $scoring_dir/$groundtruth $floor
		fi

		mv $system/$t/*.stdlist.xml $system
	done

	gzip $system/*.stdlist.xml

	echo ""
done
