#!/usr/bin/env bash

# $1: list of systems to score (absolute paths of folders containing a .stdlist.xml.gzip file)
systems=$1

# directory containing the scoring script, the .jar file and the ground-truth folders
scoring_dir=.

# python3 command (you must have Python3 installed in your system)
PYTHON3=python3

# Keyfile
keyfile=$scoring_dir/mapping3.txt

for system in $(cat $systems); do
	echo $(basename $system)

	gunzip $system/*.gz

	# The strings 'eval' or 'dev' in the system name determine the groundtruth to be used
	dev_eval=$(basename $system | sed -E 's/.*(dev|DEV|eval|EVAL).*/\1/' | sed 's/EVAL/eval/' | sed 's/DEV/dev/')

	echo "Set of queries: $dev_eval"

	# We determine whether a floor score has to be used or not
	floor=$(basename $system | sed -E 's/.*_([^_]*)/\1/')

	echo "Floor score: $floor"

	s_full=$(ls $system/*.stdlist.xml)

	for rvb in 0; do
	for db in 5; do

		id=rvb${rvb}_db${db}
		echo "Reverberation: $rvb, Noise db: $db"

		if [[ ! -e  ${id}_utts.txt ]]; then
			cat $keyfile | grep -v eval | grep -v dev | awk -v rvb=$rvb -v db=$db ' { if ($4 == rvb && $5 == db) print $2; } ' > ${id}_utts.txt
		fi
		if [[ ! -e  ${id}_${dev_eval}.txt ]]; then
			cat $keyfile | grep "${dev_eval}" | awk -v rvb=$rvb -v db=$db ' { if ($4 == rvb && $5 == db) print $2; } ' > ${id}_${dev_eval}.txt
		fi

		# Target directory, where results will be stored
		mkdir $system/$id

		s_lang=$system/$id/${id}-$(basename ${s_full})

		$PYTHON $scoring_dir/filter_std_perlang.py ${id}_utts.txt ${id}_${dev_eval}.txt ${s_full} ${s_lang}

		groundtruth=groundtruth_quesst2015_"$dev_eval"_"$id"

		if [[ $floor == "auto" ]]; then
			$scoring_dir/score-TWV-Cnxe.sh $system/$id $scoring_dir/$groundtruth
		else
			$scoring_dir/score-TWV-Cnxe.sh $system/$id $scoring_dir/$groundtruth $floor
		fi

		gzip ${s_lang}
	done
	done

	id=rvb15_db14
	echo "Reverberation: 1-5, Noise db: 1-4"

	if [[ ! -e  ${id}_utts.txt ]]; then
		cat $keyfile | grep -v eval | grep -v dev | awk ' { if ($4 != 0 && $5 != 5) print $2; } ' > ${id}_utts.txt
	fi
	if [[ ! -e  ${id}_${dev_eval}.txt ]]; then
		cat $keyfile | grep "${dev_eval}" | awk ' { if ($4 != 0 && $5 != 5) print $2; } ' > ${id}_${dev_eval}.txt
	fi

	# Target directory, where results will be stored
	mkdir $system/$id

	s_lang=$system/$id/${id}-$(basename ${s_full})

	$PYTHON $scoring_dir/filter_std_perlang.py ${id}_utts.txt ${id}_${dev_eval}.txt ${s_full} ${s_lang}

	groundtruth=groundtruth_quesst2015_"$dev_eval"_"$id"

	if [[ $floor == "auto" ]]; then
		$scoring_dir/score-TWV-Cnxe.sh $system/$id $scoring_dir/$groundtruth
	else
		$scoring_dir/score-TWV-Cnxe.sh $system/$id $scoring_dir/$groundtruth $floor
	fi

	gzip ${s_lang}
	gzip ${s_full}

	echo ""
done

for rvb in 0; do
for db in 5; do
	id=rvb${rvb}_db${db}
	if [[ -e ${id}_utts.txt ]]; then rm ${id}_utts.txt; fi
	if [[ -e ${id}_dev.txt ]]; then rm ${id}_dev.txt; fi
	if [[ -e ${id}_eval.txt ]]; then rm ${id}_eval.txt; fi
done
done
id=rvb15_db14
if [[ -e ${id}_utts.txt ]]; then rm ${id}_utts.txt; fi
if [[ -e ${id}_dev.txt ]]; then rm ${id}_dev.txt; fi
if [[ -e ${id}_eval.txt ]]; then rm ${id}_eval.txt; fi
